@@ -3,19 +3,8 @@
 """
 Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-Kajongg is free software you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation either version 2 of the License, or
-(at your option) any later version.
+SPDX-License-Identifier: GPL-2.0
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
 # pylint: disable=invalid-name,W0611
@@ -84,7 +73,6 @@ class Prompt(MustChooseKDialog, StrMixin):
     def __init__(self, msg, icon=QMessageBox.Information,
                  buttons=KDialog.Ok, caption=None, default=None):
         """buttons is button codes or-ed like KDialog.Ok | KDialog.Cancel. First one is default."""
-        MustChooseKDialog.__init__(self)
         if r'\n' in msg:
             print(r'*********************** Fix this! Prompt gets \n in', msg)
             msg = msg.replace(r'\n', '\n')
@@ -121,7 +109,6 @@ class DeferredDialog(Deferred):
     def __init__(self, dlg, modal=True, always=False):
         Deferred.__init__(self)
         self.dlg = dlg
-        self.defaultResult = dlg.returns()
         self.modal = modal
         self.always = always
         if Options.gui:
@@ -139,7 +126,7 @@ class DeferredDialog(Deferred):
     def __execute(self):
         """now do the actual action"""
         if self.dlg is None:
-            return
+            return None
         scene = Internal.scene
         if not Options.gui or not isAlive(self.dlg):
             return self.clicked()
@@ -153,6 +140,7 @@ class DeferredDialog(Deferred):
             Internal.reactor.callLater(
                 Internal.Preferences.animationDuration() / 500.0,
                 self.clicked)
+        return None
 
     def clicked(self, button=None):
         """we got a reaction"""
@@ -215,6 +203,6 @@ class Sorry(DeferredDialog):
         DeferredDialog.__init__(self, dialog, modal=modal, always=always)
 
 
-def NoPrompt(dummyMsg):
+def NoPrompt(unusedMsg):
     """we just want to be able to add callbacks even if non-interactive"""
     return succeed(None)
